"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.runActionHandler = exports.parseOutputs = exports.getInputs = exports.getInput = void 0;
const core = __importStar(require("@actions/core"));
const github_1 = require("@actions/github");
const promises_1 = require("node:fs/promises");
const verror_1 = __importDefault(require("verror"));
/**
 * Returns the value of the input, as found in the environment.
 *
 * This function parses the environment the same as core.getInput(). However, core.getInput()
 * returns an empty string when the environment variable isn't defined. The GitHub Actions engine does the
 * same when no value is provided.
 *
 * This function uses a different approach. It returns undefined if the input is not set in the environment,
 * *or if the environment variable is an empty string*. This can make it easier to set default values
 * using validation frameworks.
 *
 * @param name - The input name.
 */
function getInput(name) {
    const value = process.env[`INPUT_${name.replace(/ /g, "_").toUpperCase()}`];
    return value === "" ? undefined : value;
}
exports.getInput = getInput;
/**
 * Gets a set of inputs and returns their values in a typesafe object.
 *
 * @param inputs - The inputs to parse from the environment.
 */
function getInputs(...inputs) {
    const result = {};
    for (const input of inputs) {
        result[input] = getInput(input.toString());
    }
    return result;
}
exports.getInputs = getInputs;
/**
 * Parses the Github Actions outputs from the provided file as written by the core.setOutput
 * utility.
 *
 * The core.setOutput utility stores the outputs as heredocs with randomly generated delimiters.
 * This function parses those out and returns the remaining key value pairs as an object.
 *
 * If a key is provided more than once, the last value takes precedence.
 *
 * @param filePath - The outputs file path. Defaults to GITHUB_OUTPUT. Throws if neither the
 *  parameter and the environment variable are provided.
 *
 * @return The outputs as a record of string.
 */
async function parseOutputs(filePath) {
    const outputsPath = filePath || process.env.GITHUB_OUTPUT;
    if (outputsPath == null) {
        throw new Error(`no output file path provided as argument nor through the GITHUB_OUTPUT environment variable`);
    }
    const result = {};
    const fileContents = await (0, promises_1.readFile)(outputsPath, { encoding: "utf-8" });
    const outputRegex = /(?<key>.+?)<<(?<delimiter>.*?)\n(?<value>.*)\n\k<delimiter>\n/g;
    let captures = outputRegex.exec(fileContents);
    while (captures != null && captures.groups != null) {
        result[captures.groups.key] = captures.groups.value;
        captures = outputRegex.exec(fileContents);
    }
    return result;
}
exports.parseOutputs = parseOutputs;
/**
 * This function does away with the common boilerplate code related to running a GitHub Actions
 * handler.
 *
 * It wraps the whole process with convenient debug statements that are turned on
 * by setting ACTIONS_STEP_DEBUG to true.
 *
 * The handler can return outputs and those are forwarded automatically to core.setOutput at the
 * end of the run. core.setOutput JSON stringifies everything.
 *
 * Any runtime errors occurring during this function's execution results in a call to core.setFailed.
 *
 * @param handler - The GitHub Actions handler.
 *
 * @see https://docs.github.com/en/actions/monitoring-and-troubleshooting-workflows/enabling-debug-logging
 */
function runActionHandler(handler) {
    try {
        if (core.isDebug()) {
            core.debug(`received env: ${JSON.stringify(process.env, null, 2)}`);
            core.debug(`received context: ${JSON.stringify(github_1.context, null, 2)}`);
        }
        handler()
            .then((outputs) => {
            if (outputs == null) {
                return;
            }
            for (const [key, value] of Object.entries(outputs)) {
                if (core.isDebug()) {
                    core.debug(`setting output ${key}=${JSON.stringify(value)}`);
                }
                core.setOutput(key, value);
            }
        })
            .catch((err) => core.setFailed(verror_1.default.fullStack(err)));
    }
    catch (err) {
        core.setFailed(verror_1.default.fullStack(err));
    }
}
exports.runActionHandler = runActionHandler;
//# sourceMappingURL=index.js.map